RxMessageType

Enum RxMessageType 

pub enum RxMessageType {
    SdoTx,
    SdoRx,
    Pdo,
    Sync,
    Nmt,
    Lss,
    Guarding,
    Emcy,
    Unknown,
}
Enumeration representing the type of a received CANopen message.

This enum is used to classify the different types of CANopen messages that can be received. Each variant corresponds to a specific type of CANopen message, as indicated by the COB-ID (Communication Object Identifier).

Variants



SdoTx

Service Data Object Transmit (SDO Tx)

Represents an SDO message sent from the server (node) to the client.



SdoRx

Service Data Object Receive (SDO Rx)

Represents an SDO message sent from the client to the server (node).



Pdo

Process Data Object (PDO)

Represents any PDO message or Timestamp with COB-ID in the range 0x100 to 0x57F.



Sync

Synchronization (SYNC)

Represents a SYNC message with COB-ID 0x80.



Nmt

Network Management (NMT)

Represents an NMT message.



Lss

Layer Setting Services (LSS)

Represents an LSS message.



Guarding

Node Guarding

Represents a Node Guarding message.



Emcy

Emergency (EMCY)

Represents an EMCY message.



Unknown

Unknown Message Type

Represents a message type that could not be determined.

Implementations